@@ -40,7 +40,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.04;
+    our $VERSION = 1.05;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -66,6 +66,7 @@ my $LOG         = Log::Fast->global();    # Let's snag the Log::Fast object.
 my $MASTERSTART = time;                   # Script start timestamp.
 my ($SCRIPTNAME, $SCRIPTPATH, $suffix) = fileparse($0);
 my $PARENT      = $$;                     # Get the parent process ID
+my $TIMEZONE    = DateTime::TimeZone->new(name => 'local');
 
 =head1 NAME
 
@@ -649,7 +650,7 @@ sub _send_to_logger {    # This actually simplifies the previous object ... seri
     my $sline      = shift;
     my $shortsub   = shift;
 
-    my $dt     = DateTime->now();
+    my $dt     = DateTime->now('time_zone' => $TIMEZONE);
     my $Date   = $dt->ymd();
     my $Time   = $dt->hms();
     my $prefix = $self->{$level . '-PREFIX'} . ''; # A copy not a pointer
@@ -881,7 +882,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 1.04    (July 10, 2015 Happy Birthday to me!)
+Version 1.05    (July 27, 2015 Happy Birthday to me!)
 
 =head1 BUGS
 
